@@ -14,9 +14,9 @@ setup(### metadata:
       author_email      = 'martinal@simula.no',
       maintainer        = 'Martin Sandve Alnes',
       maintainer_email  = 'martinal@simula.no',
-      url               = 'http://www.fenics.org/ufc/',
+      url               = 'http://www.fenicsproject.org',
       description       = 'Benchmark utility for UFC implementations.',
-      download_url      = 'http://www.fenics.org/ufc/',
+      download_url      = 'https://launchpad.net/ufc',
       ### contents:
       py_modules   = ['ufc_benchmark'],
       ext_modules  = [extension],
